from PIL import Image

# ASCII characters used to build the output text
ASCII_CHARS = "@%#*+=-:. "

def resize_image(image, new_width=100):
    width, height = image.size
    aspect_ratio = height / width
    new_height = int(aspect_ratio * new_width)
    resized_image = image.resize((new_width, new_height))
    return resized_image

def grayify(image):
    grayscale_image = image.convert("L")
    return grayscale_image

def pixels_to_ascii(image):
    pixels = image.getdata()
    ascii_str = "".join([ASCII_CHARS[pixel // 25] for pixel in pixels])
    return ascii_str

def convert_image_to_ascii(image_path, new_width=100):
    try:
        image = Image.open(image_path)
    except Exception as e:
        print(e)
        return None
    
    image = resize_image(image, new_width)
    image = grayify(image)
    
    ascii_str = pixels_to_ascii(image)
    img_width = image.width
    ascii_str_len = len(ascii_str)
    ascii_img = "\n".join([ascii_str[index:(index + img_width)] for index in range(0, ascii_str_len, img_width)])
    
    return ascii_img

if __name__ == "__main__":
    import sys
    path = sys.argv[1]
    width = int(sys.argv[2]) if len(sys.argv) > 2 else 100
    print(convert_image_to_ascii(path, width))



from setuptools import setup, find_packages

setup(
    name="asciimj",
    version="0.1.0",
    author="tianhukj",
    author_email="tianhukj@outlook.com",
    description="A package to convert images to ASCII art",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/tianhukj/image-ascii",
    packages=find_packages(),
    install_requires=[
        "Pillow",
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
